# Slot: description




URI: [http://w3id.org/biolink/biolinkml/meta/value_description](slot_uri)
## Domain and Range

[Example](Example.md) -><sub>opt</sub> [String](String.md)
## Inheritance

## Children

## Used by

 * [Example](Example.md)
